log_info: Log an info message

View source: R/helpers.R

log_infoR Documentation

Log an info message

Description

Log messages will only be emitted if the log priority matches or is higher than the priority of your message

Usage

log_info(message, ...)

Arguments

message

your message to log

...

more elements of the message, to be concatenated with the message

Value

invisibly returns TRUE/FALSE

Examples

## Not run: 
log_info("This is an info message")
Sys.setenv("LOG_LEVEL" = "TRACE")
log_info("This is an info message")

## End(Not run)

rlog documentation built on March 19, 2026, 1:06 a.m.