log_warn: Log a warning message

View source: R/helpers.R

log_warnR Documentation

Log a warning message

Description

Log messages will only be emitted if the log priority matches or is higher than the priority of your message

Usage

log_warn(message, ...)

Arguments

message

your message to log

...

more elements of the message, to be concatenated with the message

Value

invisibly returns TRUE/FALSE

Examples

## Not run: 
log_warn("This is a warning message")
Sys.setenv("LOG_LEVEL" = "TRACE")
log_warn("This is a warning message")

## End(Not run)

rlog documentation built on March 19, 2026, 1:06 a.m.