| log_warn | R Documentation |
Log messages will only be emitted if the log priority matches or is higher than the priority of your message
log_warn(message, ...)
message |
your message to log |
... |
more elements of the message, to be concatenated with the message |
invisibly returns TRUE/FALSE
## Not run:
log_warn("This is a warning message")
Sys.setenv("LOG_LEVEL" = "TRACE")
log_warn("This is a warning message")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.